/**
 * @(#) ComponentLifeCycleMBean.java
 *
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: ComponentLifeCycleMBean.java 69 2006-01-17 16:00:26Z rmarins $
 * -------------------------------------------------------------------------
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.management;

/**
 * ComponentLifeCycleMBean defines the standard life cycle controls for JBI
 * Installable Components.
 * <ul>
 *   <li>Initialize the component, preparing it to receive service
 *   requests.
 *   <li>Start the component, allowing it to initiate service requests.
 *   <li>Stop the component from initiating any more service requests.
 *   <li>Shut down the component, returning it to the uninitialized state where
 *   it cannot receive service requests.
 *   <li>Query the JMX object name of the extension MBean for the
 *   component.
 * </ul>
 *
 * @author JSR208 Expert Group
 */
public interface ComponentLifeCycleMBean extends LifeCycleMBean {

	/**
     * Get the JMX ObjectName for the life cycle extension MBean for this
     * component. If there is none, return <code>null</code>. Note that this
     * MBean may serve as a container for multiple MBeans, as required by the
     * component implementation.
     * 
     * @return ObjectName the JMX object name of the additional MBean or
     *         <code>null</code> if there is no additional MBean.
     * @throws javax.jbi.JBIException
     *             if there is a failure getting component information for the
     *             component to which this life cycle applies.
     */
	public javax.management.ObjectName getExtensionMBeanName()
			throws javax.jbi.JBIException;
}
